@@ -4,7 +4,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = "0.21";
+our $VERSION = "0.35";
 
 1;
 
@@ -28,21 +28,25 @@ Many code was rewritten and optimized by XS.
 
 Gazelle supports following features.
 
-- supports HTTP/1.1. But does not have Keepalive.
+=over
 
-- ultra fast HTTP processing using picohttpparser
+=item * supports HTTP/1.1. But does not have Keepalive.
 
-- uses accept4(2) if OS support
+=item * ultra fast HTTP processing using picohttpparser
 
-- uses writev(2) for output responses
+=item * uses accept4(2) if OS support
 
-- prefork and graceful shutdown using Parallel::Prefork
+=item * uses writev(2) for output responses
 
-- hot deploy and unix domain socket using Server::Starter
+=item * prefork and graceful shutdown using Parallel::Prefork
+
+=item * hot deploy and unix domain socket using Server::Starter
+
+=back
 
 Gazelle is suitable for running HTTP application servers behind a reverse proxy like nginx.
 
-Benchmark is here. https://github.com/kazeburo/Gazelle/wiki/Benchmark
+Benchmark is here. L<https://github.com/kazeburo/Gazelle/wiki/Benchmark>
 
 =head1 SAMPLE CONFIGURATION WITH NGINX
 
@@ -87,11 +91,11 @@ max. number of requests to be handled before a worker process exits (default: 10
 
 =head2 --min-reqs-per-child=#
 
-if set, randomizes the number of requests handled by a single worker process between the value and that supplied by C<--max-reqs-per-chlid> (default: none)
+if set, randomizes the number of requests handled by a single worker process between the value and that supplied by C<--max-reqs-per-child> (default: none)
 
 =head2 --spawn-interval=#
 
-if set, worker processes will not be spawned more than once than every given seconds.  Also, when SIGHUP is being received, no more than one worker processes will be collected every given seconds.  This feature is useful for doing a "slow-restart".  See http://blog.kazuhooku.com/2011/04/web-serverstarter-parallelprefork.html for more information. (default: none)
+if set, worker processes will not be spawned more than once than every given seconds.  Also, when SIGHUP is being received, no more than one worker processes will be collected every given seconds.  This feature is useful for doing a "slow-restart".  See L<http://blog.kazuhooku.com/2011/04/web-serverstarter-parallelprefork.html> for more information. (default: none)
 
 =head1 SEE ALSO
 
